==> embutils-0.8.tar.bz2: embutils/rmdir.c <==
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <fcntl.h>

static void error(char *message) {
  write(2,"rmdir: ",6);
  write(2,message,strlen(message));
  write(2,"\n",1);
  exit(1);
}

void panic() {
  switch (errno) {
  case EPERM:
    error("permission denied");
  case EEXIST:
    error("file exists");
  case EFAULT:
    error("invalid pointer");
  case ENAMETOOLONG:
    error("name too long");
  case ENOENT:
    error("file not found");
  case ENOMEM:
    error("out of virtual memory");
  case EROFS:
    error("read-only file system");
  case EACCES:
    error("directory search permissions denied");
  case ELOOP:
    error("too many symbolic links");
  case ENOSPC:
    error("no space left on device/quota exceeded");
  case EIO:
    error("I/O error");
  default:
    error("unknown error");
  }
}

void dormdir(char *s,int v,int iexist) {
  if (rmdir(s))
    if (!iexist || errno!=EEXIST) panic();
  if (errno==0) {
    if (v) {
      write(2,"rmdir: removing directory, ",27);
      write(2,s,strlen(s));
      write(2,"\n",1);
    }
  }
}

void minusp(char *s,int v) {
  char *t=strrchr(s,'/');
  do {
    dormdir(s,v,1);
    if (t==0) return;
    *t=0;
    t=strrchr(s,'/');
  } while (1);
}

main(int argc,char *argv[]) {
  int i;
  int p=0,v=0;
  int mode=0777-umask(0);
  for (i=1; i<argc; i++) {
    if (!argv[i]) continue;
    if (argv[i][0]=='-') {
      int j;
      for (j=1; j<strlen(argv[i]); j++) {
	switch (argv[i][j]) {
	case 'p': p=1; break;
	case 'v': v=1; break;
	}
      }
    } else {
      if (p) {
	minusp(argv[i],v);
      } else
	dormdir(argv[i],v,0);
    }
  }
  return 0;
}

==> embutils-0.10.1.tar.bz2: embutils/rmdir.c <==
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <fcntl.h>

static void error(char *message) {
  write(2,"rmdir: ",6);
  write(2,message,strlen(message));
  write(2,"\n",1);
}

static int res=0;

void panic() {
  switch (errno) {
  case EPERM:
    error("permission denied"); break;
  case EEXIST:
    error("file exists"); break;
  case EFAULT:
    error("invalid pointer"); break;
  case ENAMETOOLONG:
    error("name too long"); break;
  case ENOENT:
    error("file not found"); break;
  case ENOMEM:
    error("out of virtual memory"); break;
  case EROFS:
    error("read-only file system"); break;
  case EACCES:
    error("directory search permissions denied"); break;
  case ELOOP:
    error("too many symbolic links"); break;
  case ENOSPC:
    error("no space left on device/quota exceeded"); break;
  case EIO:
    error("I/O error"); break;
  default:
    error("unknown error"); break;
  }
  res=1;
}

void dormdir(char *s,int v,int iexist) {
  if (rmdir(s))
    if (!iexist || errno!=EEXIST) { panic(); return; }
  if (errno==0) {
    if (v) {
      write(2,"rmdir: removing directory, ",27);
      write(2,s,strlen(s));
      write(2,"\n",1);
    }
  }
}

void minusp(char *s,int v) {
  char *t=strrchr(s,'/');
  do {
    dormdir(s,v,1);
    if (t==0) return;
    *t=0;
    t=strrchr(s,'/');
  } while (1);
}

main(int argc,char *argv[]) {
  int i;
  int p=0,v=0;
  int mode=0777-umask(0);
  for (i=1; i<argc; i++) {
    if (!argv[i]) continue;
    if (argv[i][0]=='-') {
      int j;
      for (j=1; j<strlen(argv[i]); j++) {
	switch (argv[i][j]) {
	case 'p': p=1; break;
	case 'v': v=1; break;
	}
      }
    } else {
      if (p) {
	minusp(argv[i],v);
      } else
	dormdir(argv[i],v,0);
    }
  }
  return res;
}
